# python-mdc [![License][license-img]][license-href] [![pipeline status][pipeline-img]][pipeline-href] [![coverage report][coverage-img]][pipeline-href]

1. [Description](#description)
2. [Limitations](#limitations)
3. [Miscellaneous](#miscellaneous)

## Description

This is a fork of vente-privee's python-mdc.  It is customized for use with HomeAssistant. 

You can install the library from PyPi using pip:
```
pip install samsung-mdc
```

Implementation of the Samsung Multiple Display Control Protocol through
Ethernet/Wireless.

## Limitations

Right now, this implementation is tested only on Samsung
[DM-E Series][dme-href] and specifically on the Samsung
[LH55DMEPLGC/EN][model-href].

## Miscellaneous

```
    ╚⊙ ⊙╝
  ╚═(███)═╝
 ╚═(███)═╝
╚═(███)═╝
 ╚═(███)═╝
  ╚═(███)═╝
   ╚═(███)═╝
```

[license-img]: https://img.shields.io/badge/license-Apache-blue.svg
[license-href]: /LICENSE
[pipeline-img]: https://git.vpgrp.io/noc/python-mdc/badges/master/pipeline.svg
[pipeline-href]: https://git.vpgrp.io/noc/python-mdc/commits/master
[coverage-img]: https://git.vpgrp.io/noc/python-mdc/badges/master/coverage.svg
[dme-href]: https://www.samsung.com/us/business/products/displays/standalone/dm-series/
[model-href]: http://www.samsung.com/nl/business/smart-signage/professional-display-dme-series/lh55dmeplgcen/
